@@ -168,25 +168,18 @@ biweight_mid_corr <- function(
   na_method <- match.arg(na_method)
 
   # --- checks
-  if (!is.numeric(c_const) || length(c_const) != 1L || !(c_const > 0))
-    stop("`c_const` must be a single positive numeric.", call. = FALSE)
-  if (!is.numeric(max_p_outliers) || length(max_p_outliers) != 1L ||
-      !(max_p_outliers > 0 && max_p_outliers <= 1))
-    stop("`max_p_outliers` must be a single numeric in (0, 1].", call. = FALSE)
-  if (!is.numeric(n_threads) || length(n_threads) != 1L || n_threads < 1)
-    n_threads <- 1L
-  n_threads <- as.integer(n_threads)
-
-  if (!is.null(w)) {
-    w <- as.numeric(w)
-    if (anyNA(w) || any(w < 0))
-      stop("`w` must be a non-negative numeric vector with no missing values.", call. = FALSE)
-  }
+  check_scalar_nonneg(c_const, arg = "c_const", strict = TRUE)
+  check_scalar_numeric(max_p_outliers,
+                       arg          = "max_p_outliers",
+                       lower        = 0,
+                       upper        = 1,
+                       closed_lower = FALSE,
+                       closed_upper = TRUE)
+  check_bool(mad_consistent, arg = "mad_consistent")
+  n_threads <- check_scalar_int_pos(n_threads, arg = "n_threads")
 
   if (!is.null(sparse_threshold)) {
-    if (!is.numeric(sparse_threshold) || length(sparse_threshold) != 1L ||
-        sparse_threshold < 0)
-      stop("`sparse_threshold` must be a single numeric >= 0.", call. = FALSE)
+    check_scalar_nonneg(sparse_threshold, arg = "sparse_threshold", strict = FALSE)
   }
 
   # --- validate/coerce input (allow NA only in pairwise mode)
@@ -196,6 +189,7 @@ biweight_mid_corr <- function(
     validate_corr_input(data, check_na = FALSE)
   }
   colnames_data <- colnames(numeric_data)
+  w <- check_weights(w, n = nrow(numeric_data), arg = "w")
 
   # --- MAD consistency via effective c
   c_eff <- if (isTRUE(mad_consistent)) c_const * 1.4826 else c_const
@@ -239,17 +233,18 @@ biweight_mid_corr <- function(
 
   # --- names & metadata
   colnames(res) <- rownames(res) <- colnames_data
-  attr(res, "method")      <- "biweight_mid_correlation"
-  attr(res, "description") <- paste0(
+  desc <- paste0(
     "Median/MAD-based biweight mid-correlation (bicor); max_p_outliers = ", max_p_outliers,
     ", MAD = ", if (mad_consistent) "normal-consistent (1.4826 * raw)" else "raw",
     "; fallback = ", pf, "; NA mode = ", na_method, "."
   )
-  attr(res, "package")     <- "matrixCorr"
 
   # --- default: dense matrix with S3 class (original behaviour)
   if (is.null(sparse_threshold)) {
-    class(res) <- c("biweight_mid_corr", "matrix")
+    res <- structure(res, class = c("biweight_mid_corr", "matrix"))
+    attr(res, "method")      <- "biweight_mid_correlation"
+    attr(res, "description") <- desc
+    attr(res, "package")     <- "matrixCorr"
     return(res)
   }
 
@@ -261,9 +256,8 @@ biweight_mid_corr <- function(
 
   res_sparse <- Matrix::Matrix(res, sparse = TRUE)
   # carry metadata; do not overwrite S4 class
-  attr(res_sparse, "method")      <- attr(res, "method")
-  attr(res_sparse, "description") <- paste0(attr(res, "description"),
-                                            " Sparse threshold = ", sparse_threshold, ".")
+  attr(res_sparse, "method")      <- "biweight_mid_correlation"
+  attr(res_sparse, "description") <- paste0(desc, " Sparse threshold = ", sparse_threshold, ".")
   attr(res_sparse, "package")     <- "matrixCorr"
   # Return S4 dsCMatrix with attrs; no S3 class assignment here
   res_sparse
@@ -299,8 +293,7 @@ print.biweight_mid_corr <- function(x,
                                     width    = getOption("width", 80L),
                                     na_print = "NA",
                                     ...) {
-  if (!inherits(x, "biweight_mid_corr"))
-    stop("x must be of class 'biweight_mid_corr'.")
+  check_inherits(x, "biweight_mid_corr")
 
   # ---- header ----
   cat("Biweight mid-correlation matrix (bicor):\n")
@@ -401,8 +394,7 @@ plot.biweight_mid_corr <- function(
     na_fill = "grey90",
     ...
 ) {
-  if (!inherits(x, "biweight_mid_corr"))
-    stop("x must be of class 'biweight_mid_corr'.")
+  check_inherits(x, "biweight_mid_corr")
 
   reorder  <- match.arg(reorder)
   triangle <- match.arg(triangle)
