@@ -83,11 +83,10 @@ schafer_corr <- function(data) {
 
   # dimnames and metadata
   colnames(result) <- rownames(result) <- colnames_data
+  result <- structure(result, class = c("schafer_corr", "matrix"))
   attr(result, "method") <- "schafer_shrinkage"
   attr(result, "description") <- "Schafer-Strimmer shrinkage correlation matrix"
   attr(result, "package") <- "matrixCorr"
-
-  class(result) <- c("schafer_corr", "matrix")
   result
 }
 
@@ -168,7 +167,7 @@ plot.schafer_corr <- function(
     palette = c("diverging", "viridis"),
     ...
 ) {
-  if (!inherits(x, "schafer_corr")) stop("x must be of class 'schafer_corr'.")
+  check_inherits(x, "schafer_corr")
   triangle <- match.arg(triangle)
   palette  <- match.arg(palette)
 
@@ -206,7 +205,7 @@ plot.schafer_corr <- function(
     )
   } else {
     if (!requireNamespace("viridisLite", quietly = TRUE)) {
-      stop("Install 'viridisLite' for palette = 'viridis'.")
+      cli::cli_abort("Package {.pkg viridisLite} is required for {.arg palette} = \"viridis\".")
     }
     fill_scale <- ggplot2::scale_fill_gradientn(
       colours = viridisLite::viridis(256, option = "B"),
